@@ -1,22 +1,23 @@
+import phonenumbers
 from django.core.management.base import BaseCommand, CommandError
 from django.utils.dateparse import parse_datetime
 from django.utils.timezone import make_aware
 
 from django_athm.conf import settings as app_settings
-from django_athm.constants import COMPLETED_STATUS, REFUNDED_STATUS
-from django_athm.models import ATHM_Item, ATHM_Transaction
+from django_athm.constants import TransactionType
+from django_athm.models import ATHM_Client, ATHM_Item, ATHM_Transaction
 
 
 def get_status(transaction):
-    if transaction["transactionType"] == "refund":
-        return REFUNDED_STATUS
-    elif transaction["transactionType"] == "ecommerce":
-        if float(transaction["refundedAmount"]) > 0:
-            return REFUNDED_STATUS
+    if transaction["transactionType"].upper() == TransactionType.refund.value:
+        return ATHM_Transaction.Status.REFUNDED
+    elif transaction["transactionType"].upper() == TransactionType.ecommerce.value:
+        if float(transaction["totalRefundAmount"]) > 0:
+            return ATHM_Transaction.Status.REFUNDED
         else:
-            return COMPLETED_STATUS
-    else:
-        return transaction["status"]
+            return ATHM_Transaction.Status.COMPLETED
+
+    return transaction["transactionType"]
 
 
 def get_defaults(transaction):
@@ -26,7 +27,7 @@ def get_defaults(transaction):
         date=make_aware(parse_datetime(transaction["date"])),
         total=float(transaction["total"]),
         tax=float(transaction["tax"]),
-        refunded_amount=float(transaction["refundedAmount"]),
+        refunded_amount=float(transaction.get("totalRefundAmount", 0)),
         subtotal=float(transaction["subtotal"]),
         metadata_1=transaction.get("metadata1", None),
         metadata_2=transaction.get("metadata2", None),
@@ -94,44 +95,62 @@ class Command(BaseCommand):
         if difference.days < 0:
             raise CommandError("Start date must be before end date!")
 
-        self.stdout.write(
-            self.style.WARNING(
-                f"Getting transactions from {start_date} to {end_date}..."
-            )
-        )
+        self.stdout.write(f"Getting transactions from {start_date} to {end_date}...")
 
         # Call the ATH Móvil API and get all transactions between the selected dates
-        athm_transactions = ATHM_Transaction.list(
-            start_date=str(start_date), end_date=str(end_date)
+        report_data = ATHM_Transaction.get_report(
+            start_date=str(start_date),
+            end_date=str(end_date),
+            public_token=public_token,
+            private_token=private_token,
         )
 
+        if "errorMessage" in report_data:
+            error_details = report_data["errorMessage"]
+            raise CommandError(error_details)
+
         self.stdout.write(
             self.style.SUCCESS(
-                f"Successfully obtained {len(athm_transactions)} transactions!"
+                f"Successfully obtained {len(report_data)} transactions!"
             )
         )
 
         # Check which transactions are already in the database
-        total_created = 0
-        total_updated = 0
+        total_transaction_created = 0
+        total_transactions_updated = 0
 
-        self.stdout.write(self.style.WARNING("Saving results to database..."))
+        total_clients_created = 0
+
+        self.stdout.write("Saving results to database...")
 
         # For each transaction, create or update an ATHM_Transaction instance
-        for transaction in athm_transactions:
-            tx_instance, tx_created = ATHM_Transaction.objects.update_or_create(
-                reference_number=transaction["referenceNumber"],
-                defaults=get_defaults(transaction),
+        for transaction_data in report_data:
+            (
+                transaction,
+                transaction_created,
+            ) = ATHM_Transaction.objects.update_or_create(
+                reference_number=transaction_data["referenceNumber"],
+                defaults=get_defaults(transaction_data),
             )
 
-            # Delete all related items if this transaction previously existed
-            if not tx_created:
-                ATHM_Item.objects.filter(transaction=tx_instance).delete()
+            phone_number_parsed = phonenumbers.parse(
+                transaction_data["phoneNumber"], "US"
+            )
+            phone_number_formatted = phonenumbers.format_number(
+                phone_number_parsed, phonenumbers.PhoneNumberFormat.E164
+            )
+
+            # Get or create an ATHM_Client instance
+            _, client_created = ATHM_Client.objects.get_or_create(
+                email=transaction_data["email"].strip(),
+                phone_number=phone_number_formatted,
+                defaults=dict(name=transaction_data["name"].strip()),
+            )
 
             # Accumulate ATHM_Item instances in this list
             item_instances = [
                 ATHM_Item(
-                    transaction=tx_instance,
+                    transaction=transaction,
                     name=item["name"],
                     description=item["description"],
                     quantity=int(item["quantity"]),
@@ -139,7 +158,7 @@ class Command(BaseCommand):
                     tax=float(item["price"]),
                     metadata=item["metadata"],
                 )
-                for item in transaction["items"]
+                for item in transaction_data["items"]
             ]
 
             # Bulk create all ATHM_Item instances, if any
@@ -147,13 +166,18 @@ class Command(BaseCommand):
                 ATHM_Item.objects.bulk_create(item_instances)
 
             # Update counts to display later
-            if tx_created:
-                total_created += 1
+            if transaction_created:
+                total_transaction_created += 1
             else:
-                total_updated += 1
+                total_transactions_updated += 1
+
+            if client_created:
+                total_clients_created += 1
 
         self.stdout.write(
             self.style.SUCCESS(
-                f"Successfully created {total_created} transactions and updated {total_updated} transactions!"
+                f"Successfully created {total_transaction_created} transaction(s), "
+                f"updated {total_transactions_updated} transaction(s), "
+                f"and created {total_clients_created} client(s)!"
             )
         )
